@@ -20,5 +20,5 @@ class DatabaseLoader:
         database = TYPE_MAPPING[db_type](self._cfg)
         self._database_proxy.initialize(database)
         database.connect()
-        database.create_tables(models)
+        database.create_tables(self._models)
         return database
